# kielbasa 
[![npm version](https://img.shields.io/npm/v/kielbasa.svg)](https://www.npmjs.com/package/kielbasa) [![GitHub license](https://img.shields.io/github/license/joshingmachine/kielbasa.svg)](https://github.com/joshingmachine/kielbasa/blob/master/LICENSE.md)

All-Natural Casing Utilities

https://en.wikipedia.org/wiki/Letter_case
